@@ -64,6 +64,8 @@
  *	@(#)diff3.c	8.1 (Berkeley) 6/6/93
  */
 
+#include "got_compat.h"
+
 #include <sys/stat.h>
 #include <sys/queue.h>
 
@@ -691,7 +693,7 @@ get_line(char **ret, FILE *b, size_t *n, struct diff3_state *d3s)
 {
 	const struct got_error *err = NULL;
 	char *cp = NULL;
-	size_t size;
+	size_t size = 0;
 	ssize_t len;
 	char *new;
 
