@@ -14,6 +14,8 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include "got_compat.h"
+
 #include <sys/queue.h>
 
 #include <errno.h>
@@ -29,6 +31,7 @@
 #include "got_object.h"
 #include "got_path.h"
 
+#include "got_lib_hash.h"
 #include "got_lib_inflate.h"
 #include "got_lib_poll.h"
 
@@ -90,8 +93,8 @@ csum_input(struct got_inflate_checksum *csum, const uint8_t *buf, size_t len)
 	if (csum->input_crc)
 		*csum->input_crc = crc32(*csum->input_crc, buf, len);
 
-	if (csum->input_sha1)
-		SHA1Update(csum->input_sha1, buf, len);
+	if (csum->input_ctx)
+		got_hash_update(csum->input_ctx, buf, len);
 }
 
 static void
@@ -100,8 +103,8 @@ csum_output(struct got_inflate_checksum *csum, const uint8_t *buf, size_t len)
 	if (csum->output_crc)
 		*csum->output_crc = crc32(*csum->output_crc, buf, len);
 
-	if (csum->output_sha1)
-		SHA1Update(csum->output_sha1, buf, len);
+	if (csum->output_ctx)
+		got_hash_update(csum->output_ctx, buf, len);
 }
 
 const struct got_error *
