@@ -29,11 +29,13 @@
 #include <time.h>
 #include <unistd.h>
 
+#include "got_compat.h"
 #include "got_error.h"
 #include "got_object.h"
 
 #include "got_lib_delta.h"
 #include "got_lib_delta_cache.h"
+#include "got_lib_hash.h"
 #include "got_lib_object.h"
 #include "got_lib_privsep.h"
 #include "got_lib_ratelimit.h"
